use ::mortality::Mortality;
use ::priority::Priority;
use ::spawner::Spawner;
use ::task::Task;



/// A Task created from another Task that is required
/// to be completed before the parent task can finish.
pub struct ChildTask<T>
{
   ///
   task: T
}



impl<T> ChildTask<T> where T: Task
{
   /// Decorates a task with the required portions
   /// needed for children of other Tasks.
   pub fn new(decorated_task: T) -> ChildTask<T>
   {
      ChildTask
      {
         task: decorated_task
      }
   }
}

impl<T> Task for ChildTask<T> where T: Task
{
   fn get_name(&self) -> &str
   {
      // Just return the contained Task's name.
      self.task.get_name()
   }

   fn get_mortality(&self) -> Mortality
   {
      // Just return the contained Task's Mortality.
      self.task.get_mortality()
   }

   fn get_priority(&self) -> Priority
   {
      // Just return the contained Task's Priority.
      self.task.get_priority()
   }

   fn reset(&mut self)
   {
      // Reset the contained Task.
      self.task.reset();
   }

   fn process(&mut self, spawner: &mut Spawner) -> bool
   {
      // Process the contained Task.
      self.task.process(spawner)
   }
}
