/// Tasks can either be removed from the processing queue or added
/// back to the queue when they are finished processing.
#[derive(Clone, Copy, PartialEq, PartialOrd, Eq, Ord)]
pub enum Mortality
{
   /// A task that will be reset when finished so that
   /// instead of dying, it is reborn.
   Immortal,

   /// A task that will be done processing when it is finished.
   Mortal
}



impl Mortality
{
   /// Get a str representation of this variant.
   pub fn to_str(&self) -> &'static str
   {
      match *self
      {
         Mortality::Immortal =>
         {
            "Immortal"
         }

         Mortality::Mortal =>
         {
            "Mortal"
         }
      }
   }

   /// Get a String representation of this variant.
   pub fn to_string(&self) -> String
   {
      String::from(self.to_str())
   }
}

impl ::std::fmt::Debug for Mortality
{
   fn fmt(&self, f: &mut ::std::fmt::Formatter) -> ::std::fmt::Result
   {
      write!(f, "{}", self.to_str())
   }
}

impl ::std::fmt::Display for Mortality
{
   fn fmt(&self, f: &mut ::std::fmt::Formatter) -> ::std::fmt::Result
   {
      write!(f, "{}", self.to_str())
   }
}
